# Example Package

This package provides some additional functions to numan (https://github.com/LemonJust/numan) for analysis of calcium imaging experiments with numerical stimuli.
Specifically, new functions for cells segmentation with CaImAn and for computing number neurons with ANOVA followed by tuning curves creation are provided.

Function new_report is adapted from https://github.com/LemonJust/numan
Functions inside compute_anova and compute_tunings are adapted from https://github.com/khalednasr/nn-numerosity-zero
